@@ -71,7 +71,7 @@ from docutils.transforms import Transform
 from domdf_python_tools.doctools import prettify_docstrings
 from domdf_python_tools.stringlist import StringList
 from pygments.lexer import Lexer  # type: ignore
-from pytest_regressions.file_regression import FileRegressionFixture  # type: ignore
+from pytest_regressions.file_regression import FileRegressionFixture
 from sphinx.builders import Builder
 from sphinx.config import Config
 from sphinx.domains import Domain, Index
